pub struct Problem { /* private fields */ }Expand description
Information about the breaking of the lint
Implementations
sourceimpl Problem
impl Problem
sourcepub fn new(
error: String,
tip: String,
code: Code,
commit_message: &CommitMessage<'_>,
labels: Option<Vec<(String, usize, usize)>>,
url: Option<String>
) -> Self
pub fn new(
error: String,
tip: String,
code: Code,
commit_message: &CommitMessage<'_>,
labels: Option<Vec<(String, usize, usize)>>,
url: Option<String>
) -> Self
Create a new problem
Examples
use std::option::Option::None;
use mit_lint::{Code, Problem};
let problem = Problem::new(
"Error title".to_string(),
"Some advice on how to fix it".to_string(),
Code::BodyWiderThan72Characters,
&"Commit Message".into(),
None,
None,
);
assert_eq!(problem.error(), "Error title".to_string())sourcepub const fn code(&self) -> &Code
pub const fn code(&self) -> &Code
Get the code for this problem
Examples
use std::option::Option::None;
use mit_lint::{Code, Problem};
let problem = Problem::new(
"Error title".to_string(),
"Some advice on how to fix it".to_string(),
Code::BodyWiderThan72Characters,
&"Commit Message".into(),
None,
None,
);
assert_eq!(problem.code(), &Code::BodyWiderThan72Characters)sourcepub fn commit_message(&self) -> CommitMessage<'_>
pub fn commit_message(&self) -> CommitMessage<'_>
Get the commit message for this problem
Examples
use std::option::Option::None;
use mit_commit::CommitMessage;
use mit_lint::{Code, Problem};
let problem = Problem::new(
"Error title".to_string(),
"Some advice on how to fix it".to_string(),
Code::BodyWiderThan72Characters,
&"Commit Message".into(),
None,
None,
);
assert_eq!(
problem.commit_message(),
CommitMessage::from("Commit Message")
)sourcepub fn error(&self) -> &str
pub fn error(&self) -> &str
Get the descriptive title for this error
Examples
use std::option::Option::None;
use mit_lint::{Code, Problem};
let problem = Problem::new(
"Error title".to_string(),
"Some advice on how to fix it".to_string(),
Code::BodyWiderThan72Characters,
&"Commit Message".into(),
None,
None,
);
assert_eq!(problem.error(), "Error title".to_string())sourcepub fn tip(&self) -> &str
pub fn tip(&self) -> &str
Get advice on how to fix the problem
This should be a description of why this is a problem, and how to fix it
Examples
use std::option::Option::None;
use mit_lint::{Code, Problem};
let problem = Problem::new(
"Error title".to_string(),
"Some advice on how to fix it".to_string(),
Code::BodyWiderThan72Characters,
&"Commit Message".into(),
None,
None,
);
assert_eq!(problem.tip(), "Some advice on how to fix it".to_string())Trait Implementations
sourceimpl Diagnostic for Problem
impl Diagnostic for Problem
sourcefn code<'a>(&'a self) -> Option<Box<dyn Display + 'a>>
fn code<'a>(&'a self) -> Option<Box<dyn Display + 'a>>
Unique diagnostic code that can be used to look up more information
about this Diagnostic. Ideally also globally unique, and documented in
the toplevel crate’s documentation for easy searching. Rust path
format (foo::bar::baz) is recommended, but more classic codes like
E0123 or Enums will work just fine.
sourcefn help<'a>(&'a self) -> Option<Box<dyn Display + 'a>>
fn help<'a>(&'a self) -> Option<Box<dyn Display + 'a>>
Additional help text related to this Diagnostic. Do you have any advice for the poor soul who’s just run into this issue?
sourcefn source_code(&self) -> Option<&dyn SourceCode>
fn source_code(&self) -> Option<&dyn SourceCode>
Source code to apply this
Diagnostic’s Diagnostic::labels to.sourcefn labels(&self) -> Option<Box<dyn Iterator<Item = LabeledSpan> + '_>>
fn labels(&self) -> Option<Box<dyn Iterator<Item = LabeledSpan> + '_>>
Labels to apply to this
Diagnostic’s Diagnostic::source_codesourcefn url<'a>(&'a self) -> Option<Box<dyn Display + 'a>>
fn url<'a>(&'a self) -> Option<Box<dyn Display + 'a>>
URL to visit for a more detailed explanation/help about this
Diagnostic.sourcefn severity(&self) -> Option<Severity>
fn severity(&self) -> Option<Severity>
Diagnostic severity. This may be used by
ReportHandlers to change the display format
of this diagnostic. Read moreAdditional related
Diagnostics.sourcefn diagnostic_source(&self) -> Option<&dyn Diagnostic>
fn diagnostic_source(&self) -> Option<&dyn Diagnostic>
The cause of the error.
sourceimpl Error for Problem
impl Error for Problem
1.30.0 · sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
The lower-level source of this error, if any. Read more
1.0.0 · sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0: use the Display impl or to_string()
sourceimpl PartialEq<Problem> for Problem
impl PartialEq<Problem> for Problem
impl Eq for Problem
impl StructuralEq for Problem
impl StructuralPartialEq for Problem